@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vladzzag@gmail.com>
+    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -89,6 +89,14 @@ public:
      * The returned unit symbol is localized.
      */
     static QString symbol(Unit unit);
+
+    /**
+     * Return the maximum length of a formatted string for the specified unit and font.
+     *
+     * @param unit The unit to use.
+     * @param font The font to use.
+     */
+    static qreal maximumLength(Unit unit, const QFont &font);
 };
 
 } // namespace KSysGuard
