@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vladzzag@gmail.com>
+    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -87,7 +87,8 @@ enum Unit {
     UnitRpm,
     UnitVolt,
     UnitWatt,
-    UnitWattHour
+    UnitWattHour,
+    UnitAmpere
 };
 Q_ENUM_NS(Unit)
 
