@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vladzzag@gmail.com>
+    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
     Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
     This library is free software; you can redistribute it and/or
@@ -18,15 +18,23 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "Sensor.h"
+
+#include <optional>
+#include <chrono>
+
 #include <QEvent>
 
+#include "formatter/Formatter.h"
+#include "systemstats/SensorInfo.h"
+
 #include "Sensor.h"
 #include "SensorDaemonInterface_p.h"
-#include "SensorInfo_p.h"
-#include "formatter/Formatter.h"
 #include "SensorQuery.h"
 
+
 using namespace KSysGuard;
+namespace chrono = std::chrono;
 
 class Q_DECL_HIDDEN Sensor::Private
 {
@@ -43,6 +51,9 @@ public:
     QString id;
 
     bool enabled = true;
+
+    std::optional<int> updateRateLimit;
+    chrono::steady_clock::time_point lastUpdate;
 };
 
 Sensor::Sensor(QObject *parent)
@@ -209,6 +220,37 @@ uint Sensor::updateInterval() const
     return BackendUpdateInterval;
 }
 
+int Sensor::updateRateLimit() const
+{
+    return d->updateRateLimit.value_or(-1);
+}
+
+void Sensor::setUpdateRateLimit(int newUpdateRateLimit)
+{
+    // An update rate limit of 0 or less makes no sense, so treat it as clearing
+    // the limit.
+    if (newUpdateRateLimit <= 0) {
+        if (!d->updateRateLimit) {
+            return;
+        }
+
+        d->updateRateLimit.reset();
+    } else {
+        if (d->updateRateLimit && d->updateRateLimit.value() == newUpdateRateLimit) {
+            return;
+        }
+
+        d->updateRateLimit = newUpdateRateLimit;
+    }
+    d->lastUpdate = chrono::steady_clock::now();
+    Q_EMIT updateRateLimitChanged();
+}
+
+void KSysGuard::Sensor::resetUpdateRateLimit()
+{
+    setUpdateRateLimit(-1);
+}
+
 void Sensor::classBegin()
 {
     d->usedByQml = true;
@@ -247,6 +289,16 @@ void Sensor::onValueChanged(const QString &sensorId, const QVariant &value)
         return;
     }
 
+    if (d->updateRateLimit) {
+        auto updateRateLimit = chrono::steady_clock::duration(chrono::milliseconds(d->updateRateLimit.value()));
+        auto now = chrono::steady_clock::now();
+        if (now - d->lastUpdate < updateRateLimit) {
+            return;
+        } else {
+            d->lastUpdate = now;
+        }
+    }
+
     d->value = value;
     Q_EMIT valueChanged();
 }
